@@ -9,7 +9,7 @@
 
 from __future__ import with_statement
 
-__version__ = '0.5.18'
+__version__ = '0.5.20'
 
 # import sip
 # sip.setapi('QString', 2)
@@ -33,69 +33,17 @@ except:
 
 from qbadgebutton import QToolBadgeButton
 
-
-
 import os
 import sys
 from list_view import KhweetsView
 from list_model import KhweetsModel, ISMEROLE, IDROLE, ORIGINROLE, SCREENNAMEROLE, PROTECTEDROLE, USERIDROLE
 
-import dbus.service
 
 try:
     from QtMobility.Location import QGeoPositionInfoSource
 except:
     print 'Pyside QtMobility not installed or broken'
 
-class KhweeteurDBusHandler(dbus.service.Object):
-
-    def __init__(self, parent):
-        dbus.service.Object.__init__(self, dbus.SessionBus(),
-                                     '/net/khertan/Khweeteur')
-        self.parent = parent
-
-        # Post Folder
-
-        self.post_path = os.path.join(os.path.expanduser('~'), '.khweeteur',
-                                      'topost')
-
-    @dbus.service.signal(dbus_interface='net.khertan.Khweeteur')
-    def require_update(self, optional=None):
-        try:
-            self.parent.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
-        except:
-            pass
-
-    def post_tweet(
-        self,
-        shorten_url=1,
-        serialize=1,
-        text='',
-        lattitude='0',
-        longitude='0',
-        base_url='',
-        action='',
-        tweet_id='0',
-        ):
-        import time
-        import pickle
-        if not os.path.exists(self.post_path):
-            os.makedirs(self.post_path)
-        with open(os.path.join(self.post_path, str(time.time())), 'wb') as \
-            fhandle:
-            post = {
-                'shorten_url': shorten_url,
-                'serialize': serialize,
-                'text': text,
-                'lattitude': lattitude,
-                'longitude': longitude,
-                'base_url': base_url,
-                'action': action,
-                'tweet_id': tweet_id,
-                }
-            pickle.dump(post, fhandle, pickle.HIGHEST_PROTOCOL)
-
-
 class KhweeteurAbout(QMainWindow):
 
     '''About Window'''
@@ -107,12 +55,7 @@ class KhweeteurAbout(QMainWindow):
         self.settings = QSettings()
 
         try:  # Preferences not set yet
-            if int(self.settings.value('useAutoRotation')) == 2:
-                self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        except:
             self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-
-        try:
             self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
         except:
             pass
@@ -287,8 +230,6 @@ class Khweeteur(QApplication):
     def run(self):
         self.check_crash_report()
         self.win = KhweeteurWin()
-        self.win.show()
-
 
 class KhweeteurWin(QMainWindow):
 
@@ -302,6 +243,7 @@ class KhweeteurWin(QMainWindow):
             self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
         except:
             pass
+
         self.setWindowTitle('Khweeteur')
 
         settings = QSettings()
@@ -395,6 +337,14 @@ class KhweeteurWin(QMainWindow):
         self.tb_list_button.clicked.connect(self.show_list)
         self.list_tb_action.append(self.toolbar.addWidget(self.tb_list_button))
 
+        # Near (Default)
+        self.near_button = QToolBadgeButton(self)
+        self.near_button.setText('Nears')
+        self.near_button.setIcon(QIcon.fromTheme('general_web'))
+        self.near_button.setCheckable(True)
+        self.near_button.clicked.connect(self.show_nears)
+        self.list_tb_action.append(self.toolbar.addWidget(self.near_button))
+
         # Fullscreen
 
         self.tb_fullscreen = QAction(QIcon.fromTheme('general_fullsize'),
@@ -403,42 +353,29 @@ class KhweeteurWin(QMainWindow):
         self.toolbar.addAction(self.tb_fullscreen)
         self.list_tb_action.append(self.tb_fullscreen)
 
-        # Actions not in toolbar
-
-        self.tb_scrolltop = QAction('Scroll to top', self)
-        self.tb_scrolltop.setShortcut(Qt.CTRL + Qt.Key_Up)
-        self.tb_scrolltop.triggered.connect(self.view.scrollToTop)
-        self.addAction(self.tb_scrolltop)
-
-        self.tb_scrollbottom = QAction('Scroll to bottom', self)
-        self.tb_scrollbottom.setShortcut(Qt.CTRL + Qt.Key_Down)
-        self.tb_scrollbottom.triggered.connect(self.view.scrollToBottom)
-        self.addAction(self.tb_scrollbottom)
-
-        self.tb_zoomin = QAction('ZoomIn', self)
-        self.tb_zoomin.setShortcut(Qt.CTRL + Qt.Key_Left)
-        self.tb_zoomin.triggered.connect(self.view.do_zoom_in)
-        self.addAction(self.tb_zoomin)
-
-        self.tb_zoomout = QAction('ZoomOut', self)
-        self.tb_zoomout.setShortcut(Qt.CTRL + Qt.Key_Right)
-        self.tb_zoomout.triggered.connect(self.view.do_zoom_out)
-        self.addAction(self.tb_zoomout)
-
-        self.tb_copy = QAction('Copy', self)
-        self.tb_copy.setShortcut(Qt.CTRL + Qt.Key_C)
-        self.tb_copy.triggered.connect(self.do_tb_copy)
-        self.addAction(self.tb_copy)
-
-#        self.switch_tb_default()
-
         self.setWindowTitle('Khweeteur : Home')
-        self.model.load('HomeTimeline')
+
         self.show()
-        QTimer.singleShot(500,self.post_init)
+
+        self.model.load('HomeTimeline',limit=5)
+        QTimer.singleShot(100,self.post_init_2)
+        QTimer.singleShot(500,self.post_init_3)
+        QApplication.processEvents()
 
     @Slot()
-    def post_init(self):
+    def post_init_3(self):
+        self.model.load('HomeTimeline')
+        #Check if there is at least one account
+        nb_accounts = QSettings().beginReadArray('accounts')
+        if not nb_accounts:
+            if not (( QMessageBox.question(None,
+                "Kheeteur",
+                'None microblogging account found, would you want to add one now in preferences ?',
+                QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+                    self.showPrefs()
+
+    @Slot()
+    def post_init_2(self):
         self.listen_dbus()
         self.dbus_handler.require_update()
         self.tb_update.triggered.connect(self.dbus_handler.require_update)
@@ -553,6 +490,33 @@ class KhweeteurWin(QMainWindow):
         self.tb_delete.triggered.connect(self.do_tb_delete)
         self.action_tb_action.append(self.tb_delete)
 
+        # Actions not in toolbar
+
+        self.tb_scrolltop = QAction('Scroll to top', self)
+        self.tb_scrolltop.setShortcut(Qt.CTRL + Qt.Key_Up)
+        self.tb_scrolltop.triggered.connect(self.view.scrollToTop)
+        self.addAction(self.tb_scrolltop)
+
+        self.tb_scrollbottom = QAction('Scroll to bottom', self)
+        self.tb_scrollbottom.setShortcut(Qt.CTRL + Qt.Key_Down)
+        self.tb_scrollbottom.triggered.connect(self.view.scrollToBottom)
+        self.addAction(self.tb_scrollbottom)
+
+        self.tb_zoomin = QAction('ZoomIn', self)
+        self.tb_zoomin.setShortcut(Qt.CTRL + Qt.Key_Left)
+        self.tb_zoomin.triggered.connect(self.view.do_zoom_in)
+        self.addAction(self.tb_zoomin)
+
+        self.tb_zoomout = QAction('ZoomOut', self)
+        self.tb_zoomout.setShortcut(Qt.CTRL + Qt.Key_Right)
+        self.tb_zoomout.triggered.connect(self.view.do_zoom_out)
+        self.addAction(self.tb_zoomout)
+
+        self.tb_copy = QAction('Copy', self)
+        self.tb_copy.setShortcut(Qt.CTRL + Qt.Key_C)
+        self.tb_copy.triggered.connect(self.do_tb_copy)
+        self.addAction(self.tb_copy)
+
     @Slot()
     def do_tb_fullscreen(self):
         if self.isFullScreen():
@@ -581,6 +545,7 @@ class KhweeteurWin(QMainWindow):
         import dbus
         import dbus.service
         from dbusobj import KhweeteurDBus
+        from dbushandler import KhweeteurDBusHandler
         from dbus.mainloop.qt import DBusQtMainLoop
         self.dbus_loop = DBusQtMainLoop()
         dbus.set_default_main_loop(self.dbus_loop)
@@ -602,7 +567,10 @@ class KhweeteurWin(QMainWindow):
         dbusobj.attach_win(self)
 
     def stop_spinning(self):
-        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+        try:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+        except AttributeError:
+            pass
 
     def new_tweets(self, count, msg):
         if msg == 'HomeTimeline':
@@ -615,6 +583,9 @@ class KhweeteurWin(QMainWindow):
         elif msg == 'DMs':
             self.msg_button.setCounter(self.msg_button.getCounter() + count)
             self.msg_button.update()
+        elif msg == 'Nears':
+            self.near_button.setCounter(self.near_button.getCounter() + count)
+            self.near_button.update()
         elif msg.startswith('Search:'):
             self.tb_search_button.setCounter(self.tb_search_button.getCounter()
                     + count)
@@ -636,6 +607,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_search_button.setChecked(True)
         self.mention_button.setChecked(False)
         self.tb_list_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('Search:' + terms)
         self.delete_search_action.setVisible(True)
@@ -653,6 +625,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_search_button.setChecked(False)
         self.tb_list_button.setChecked(True)
         self.mention_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('List:' + user + ':' + tid)
         self.delete_search_action.setVisible(True)
@@ -664,6 +637,7 @@ class KhweeteurWin(QMainWindow):
         self.home_button.setChecked(True)
         self.msg_button.setChecked(False)
         self.tb_search_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.tb_list_button.setChecked(False)
         self.mention_button.setChecked(False)
         self.view.scrollToTop()
@@ -987,6 +961,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_list_button.setChecked(False)
         self.tb_search_button.setChecked(False)
         self.home_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('Mentions')
         self.setWindowTitle('Khweeteur : Mentions')
@@ -1000,11 +975,37 @@ class KhweeteurWin(QMainWindow):
         self.home_button.setChecked(False)
         self.tb_search_button.setChecked(False)
         self.mention_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('DMs')
         self.setWindowTitle('Khweeteur : DMs')
         self.delete_search_action.setVisible(False)
 
+    @Slot()
+    def show_nears(self):
+        settings = QSettings()
+        if settings.value('useGPS') != '2':
+            if not (( QMessageBox.question(None,
+                "Kheeteur",
+                'This feature require the activation of the GPS, would you want to activate it now ?',
+                QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+                    settings.setValue('useGPS','2')
+                    settings.sync()
+                    self.geolocDoStart()
+                    self.dbus_handler.require_update()
+
+        self.near_button.setCounter(0)
+        self.near_button.setChecked(True)
+        self.msg_button.setChecked(False)
+        self.tb_list_button.setChecked(False)
+        self.home_button.setChecked(False)
+        self.tb_search_button.setChecked(False)
+        self.mention_button.setChecked(False)
+        self.view.scrollToTop()
+        self.model.load('Nears')
+        self.setWindowTitle('Khweeteur : Near Tweets')
+        self.delete_search_action.setVisible(False)
+
     @Slot()
     def countCharsAndResize(self):
         local_self = self.tb_text
